@@ -1,23 +1,15 @@
 package DateTime::Format::EraLegis;
 {
-  $DateTime::Format::EraLegis::VERSION = '0.001';
+  $DateTime::Format::EraLegis::VERSION = '0.002';
 }
 
 # ABSTRACT: DateTime formatter for Era Legis (http://oto-usa.org/calendar.html)
 
 use 5.010;
-use Moose;
-use MooseX::Attribute::Chained;
+use Any::Moose;
 use JSON;
 use Method::Signatures;
 
-has 'format' => (
-    traits => ['Chained'],
-    is => 'rw',
-    isa => 'Str',
-    default => '',
-    );
-
 has 'ephem' => (
     is => 'ro',
     isa => 'DateTime::Format::EraLegis::Ephem',
@@ -25,21 +17,21 @@ has 'ephem' => (
     );
 
 has 'style' => (
-    is => 'rw',
+    is => 'ro',
     isa => 'DateTime::Format::EraLegis::Style',
     lazy_build => 1,
     );
 
 method _build_ephem {
-    return DateTime::Format::EraLegis::Ephem->new();
+    return DateTime::Format::EraLegis::Ephem->new;
 }
 
 method _build_style {
-    return DateTime::Format::EraLegis::Style->new();
+    return DateTime::Format::EraLegis::Style->new;
 }
 
 
-method format_datetime(DateTime $dt) {
+method format_datetime(DateTime $dt, Str $format = 'plain') {
     $dt = $dt->clone;
 
     ### Day of week should match existing time zone
@@ -62,10 +54,10 @@ method format_datetime(DateTime $dt) {
 
     $tdate{plain} = $self->style->express( \%tdate );
 
-    if ($self->format eq 'json') {
+    if ($format eq 'json') {
         return JSON->new->pretty->encode(\%tdate);
     }
-    elsif ($self->format eq 'raw') {
+    elsif ($format eq 'raw') {
         return \%tdate;
     }
     else {
@@ -75,16 +67,16 @@ method format_datetime(DateTime $dt) {
 
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
+no Any::Moose;
 
 ######################################################
 package DateTime::Format::EraLegis::Ephem;
 {
-  $DateTime::Format::EraLegis::Ephem::VERSION = '0.001';
+  $DateTime::Format::EraLegis::Ephem::VERSION = '0.002';
 }
 
 use 5.010;
-use Moose;
+use Any::Moose;
 use Carp;
 use DBI;
 use Method::Signatures;
@@ -124,27 +116,24 @@ method lookup(Str $body, DateTime $dt) {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
+no Any::Moose;
 
 ######################################################
 
 package DateTime::Format::EraLegis::Style;
 {
-  $DateTime::Format::EraLegis::Style::VERSION = '0.001';
+  $DateTime::Format::EraLegis::Style::VERSION = '0.002';
 }
 
 use 5.010;
-use Moose;
+use Any::Moose;
 use utf8;
 use Roman::Unicode qw(to_roman);
-use Moose::Util::TypeConstraints;
 use Method::Signatures;
 
-enum 'Language', [qw( latin symbol english poor-latin )];
-
 has 'lang' => (
     is => 'ro',
-    isa => 'Language',
+    isa => 'Str',
     default => 'latin',
     required => 1,
     );
@@ -262,5 +251,154 @@ method express( HashRef $tdate ) {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
+no Any::Moose;
 1;
+
+__END__
+
+=head1 NAME
+
+DateTime::Format::EraLegis - DateTime converter for Era Legis
+DateTime::Format::EraLegis::Ephem - planetary ephemeris data
+DateTime::Format::EraLegis::Style - customize output styles
+
+=head1 SYNOPSIS
+
+ use DateTime::Format::EraLegis;
+
+ my $ephem = DateTime::Format::EraLegis::Ephem->new(
+     ephem_db => 'db.sqlite3');
+ my $style = DateTime::Format::EraLegis::Style->new(
+     show_terse => 1, lang => 'symbol');
+ my $dtf = DateTime::Format::EraLegis->new(
+     ephem => $ephem, style => $style);
+
+ my $dt->set_formatter($dtf);
+
+=head1 DESCRIPTION
+
+These three modules combined enable DateTime objects to emit date strings
+formatted according to the Thelemic calendar. The ephemeris provides access
+to the planetary location of the Sun and Moon keyed by UTC timestamp. The
+style dictates the specific expression of the of datetime value using a
+template into which one can place tokens which can be converted into the
+sign/degree coordinates for the given date. A default style exists and is
+permutable by boolean attributes.
+
+All three classes are built with Moose and behave accordingly. Method
+arguments are typechecked and will die on failure. Defaults exist for
+all attributes. All attributes are read-only and must be assigned at
+the time of instantiation.
+
+=head1 ATTRIBUTES AND METHODS
+
+=over
+
+=item *
+
+DateTime::Format::EraLegis
+
+=over
+
+=item *
+
+ephem: DT::F::EL::Ephem object. Creates a new one by default.
+
+=item *
+
+style: DT::F::EL::Style object. Creates a new one by default.
+
+=item *
+
+format_datetime(DateTime $dt, Str $format): Standard interface for a
+DateTime::Format package. $format is one of 'plain', 'json', or 'raw'.
+Defaults to 'plain'.
+
+=back
+
+=item *
+
+DateTime::Format::Ephem
+
+=over
+
+=item *
+
+ephem_db: Filename of the sqlite3 ephemeris database. Defaults to the value
+of $ENV{ERALEGIS_EPHEMDB}.
+
+=item *
+
+dbh: DBI handle for ephemeris database. Defaults to creating a new one pointing
+to the ephem_db database.
+
+=item *
+
+lookup(Str $body, DateTime $dt): $body is one of "sol" or "luna". $dt is the
+date in question (in UTC!). Returns the number of degrees away from 0 degrees
+Aries. Divide by thirty to get the sign. Modulo by thirty to get the degrees
+of that sign.
+
+=back
+
+=item *
+
+DateTime::Format::EraLegis::Style
+
+=over
+
+=item *
+
+template: Assign a custom template value. Variables (enclosed in '{}')
+include 'ssign' and 'sdeg' for Sol sign and degree, 'lsign' and 'ldeg'
+for Luna sign and degree, 'dow' for day of the week, and 'year1' and
+'year2' for the two docosades. Example:
+
+ "Sol in {sdeg} degrees {ssign}, anno {year1}{year2} era legis"
+
+Interpolated values get assigned based on the setting of 'lang'.
+
+=item *
+
+lang: Set the output language, one of latin, english, symbol, poor-latin.
+Defaults to 'latin'.
+
+=item *
+
+show_terse, show_deg, show_dow, show_year, roman_year: Flags to direct
+the style to alter the default template.
+
+=back
+
+=back
+
+=head1 DATABASE SCHEMA
+
+The schema is very simple and the querying SQL very generic. Most DBI
+backends should work without issue, though SQLite3 is the only tested
+one. The schema is:
+
+ CREATE TABLE ephem (
+   body TEXT,               -- one of 'sol' or 'luna'
+   time DATETIME,           -- UTC timestamp of shift into degree
+   degree INTEGER NOT NULL, -- degrees from 0 degrees Aries
+   PRIMARY KEY (body, time)
+ );
+
+=head1 BUGS
+
+Please report bugs via GitHub issues:
+https://github.com/ctfliblime/DateTime-Format-EraLegis
+
+=head1 AUTHOR
+
+Clay Fouts <cfouts@khephera.net>
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright (c) 2012 Clay Fouts
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
